@@ -14,9 +14,6 @@ import (
 	"os"
 	"strings"
 
-	"github.com/coreos/pkg/capnslog"
-	"github.com/coreos/pkg/flagutil"
-
 	"github.com/openshift/console/pkg/auth"
 	"github.com/openshift/console/pkg/bridge"
 	"github.com/openshift/console/pkg/knative"
@@ -24,10 +21,8 @@ import (
 	"github.com/openshift/console/pkg/server"
 	"github.com/openshift/console/pkg/serverconfig"
 	oscrypto "github.com/openshift/library-go/pkg/crypto"
-)
 
-var (
-	log = capnslog.NewPackageLogger("github.com/openshift/console", "cmd/main")
+	"k8s.io/klog"
 )
 
 const (
@@ -57,19 +52,21 @@ const (
 	openshiftMeteringHost = "reporting-operator.openshift-metering.svc:8080"
 
 	// Well-known location of the GitOps service. This is only accessible in-cluster
-	openshiftGitOpsHost = "cluster.openshift-pipelines-app-delivery.svc:8080"
+	openshiftGitOpsHost = "cluster.openshift-gitops.svc:8080"
 )
 
 func main() {
-	rl := capnslog.MustRepoLogger("github.com/openshift/console")
-	capnslog.SetFormatter(capnslog.NewStringFormatter(os.Stderr))
-
 	fs := flag.NewFlagSet("bridge", flag.ExitOnError)
+	klog.InitFlags(fs)
+	defer klog.Flush()
+
+	// Define commandline / env / config options
+	fs.String("config", "", "The YAML config file.")
+
 	fListen := fs.String("listen", "http://0.0.0.0:9000", "")
 
 	fBaseAddress := fs.String("base-address", "", "Format: <http | https>://domainOrIPAddress[:port]. Example: https://openshift.example.com.")
 	fBasePath := fs.String("base-path", "/", "")
-	fConfig := fs.String("config", "", "The YAML config file.")
 
 	// See https://github.com/openshift/service-serving-cert-signer
 	fServiceCAFile := fs.String("service-ca-file", "", "CA bundle for OpenShift services signed with the service signing certificates.")
@@ -123,24 +120,23 @@ func main() {
 	fPrometheusPublicURL := fs.String("prometheus-public-url", "", "Public URL of the cluster's Prometheus server.")
 	fThanosPublicURL := fs.String("thanos-public-url", "", "Public URL of the cluster's Thanos server.")
 
+	consolePluginsFlags := serverconfig.MultiKeyValue{}
+	fs.Var(&consolePluginsFlags, "plugins", "List of plugin entries that are enabled for the console. Each entry consist of plugin-name as a key and plugin-endpoint as a value.")
+
 	fLoadTestFactor := fs.Int("load-test-factor", 0, "DEV ONLY. The factor used to multiply k8s API list responses for load testing purposes.")
 
-	if err := fs.Parse(os.Args[1:]); err != nil {
+	fDevCatalogCategories := fs.String("developer-catalog-categories", "", "Allow catalog categories customization. (JSON as string)")
+	fUserSettingsLocation := fs.String("user-settings-location", "configmap", "DEV ONLY. Define where the user settings should be stored. (configmap | localstorage).")
+
+	if err := serverconfig.Parse(fs, os.Args[1:], "BRIDGE"); err != nil {
 		fmt.Fprintln(os.Stderr, err.Error())
 		os.Exit(1)
 	}
-
-	if err := flagutil.SetFlagsFromEnv(fs, "BRIDGE"); err != nil {
+	if err := serverconfig.Validate(fs); err != nil {
 		fmt.Fprintln(os.Stderr, err.Error())
 		os.Exit(1)
 	}
 
-	if *fConfig != "" {
-		if err := serverconfig.SetFlagsFromConfig(fs, *fConfig); err != nil {
-			log.Fatalf("Failed to load config: %v", err)
-		}
-	}
-
 	baseURL := &url.URL{}
 	if *fBaseAddress != "" {
 		baseURL = bridge.ValidateFlagIsURL("base-address", *fBaseAddress)
@@ -207,18 +203,26 @@ func main() {
 
 	if *fCustomLogoFile != "" {
 		if _, err := os.Stat(*fCustomLogoFile); err != nil {
-			log.Fatalf("could not read logo file: %v", err)
+			klog.Fatalf("could not read logo file: %v", err)
 		}
 	}
 
 	if *fInactivityTimeout < 300 {
-		log.Warning("Flag inactivity-timeout is set to less then 300 seconds and will be ignored!")
+		klog.Warning("Flag inactivity-timeout is set to less then 300 seconds and will be ignored!")
 	} else {
 		if *fK8sAuth != "oidc" && *fK8sAuth != "openshift" {
 			fmt.Fprintln(os.Stderr, "In order activate the user inactivity timout, flag --user-auth must be one of: oidc, openshift")
 			os.Exit(1)
 		}
-		log.Infof("Setting user inactivity timout to %d seconds", *fInactivityTimeout)
+		klog.Infof("Setting user inactivity timout to %d seconds", *fInactivityTimeout)
+	}
+
+	consolePluginsMap := consolePluginsFlags.ToMap()
+	if len(consolePluginsMap) > 0 {
+		klog.Infoln("The following console plugins are enabled:")
+		for pluginName, _ := range consolePluginsMap {
+			klog.Infof(" - %s\n", pluginName)
+		}
 	}
 
 	srv := &server.Server{
@@ -236,6 +240,9 @@ func main() {
 		ThanosPublicURL:       thanosPublicURL,
 		LoadTestFactor:        *fLoadTestFactor,
 		InactivityTimeout:     *fInactivityTimeout,
+		DevCatalogCategories:  *fDevCatalogCategories,
+		UserSettingsLocation:  *fUserSettingsLocation,
+		EnabledConsolePlugins: consolePluginsMap,
 	}
 
 	// if !in-cluster (dev) we should not pass these values to the frontend
@@ -254,14 +261,8 @@ func main() {
 		os.Exit(1)
 	}
 
-	capnslog.SetGlobalLogLevel(capnslog.INFO)
 	if *fLogLevel != "" {
-		llc, err := rl.ParseLogLevelConfig(*fLogLevel)
-		if err != nil {
-			log.Fatal(err)
-		}
-		rl.SetLogLevel(llc)
-		log.Infof("Setting log level to %s", *fLogLevel)
+		klog.Warningf("DEPRECATED: --log-level is now deprecated, use verbosity flag --v=Level instead")
 	}
 
 	var (
@@ -277,17 +278,17 @@ func main() {
 		var err error
 
 		if srv.DexClient, err = auth.NewDexClient(*fDexAPIHost, *fDexClientCAFile, *fDexClientCertFile, *fDexClientKeyFile); err != nil {
-			log.Fatalf("Failed to create a Dex API client: %v", err)
+			klog.Fatalf("Failed to create a Dex API client: %v", err)
 		}
 	}
 
 	var secureCookies bool
 	if baseURL.Scheme == "https" {
 		secureCookies = true
-		log.Info("cookies are secure!")
+		klog.Info("cookies are secure!")
 	} else {
 		secureCookies = false
-		log.Warning("cookies are not secure because base-address is not https!")
+		klog.Warning("cookies are not secure because base-address is not https!")
 	}
 
 	var k8sEndpoint *url.URL
@@ -298,11 +299,11 @@ func main() {
 		var err error
 		k8sCertPEM, err = ioutil.ReadFile(k8sInClusterCA)
 		if err != nil {
-			log.Fatalf("Error inferring Kubernetes config from environment: %v", err)
+			klog.Fatalf("Error inferring Kubernetes config from environment: %v", err)
 		}
 		rootCAs := x509.NewCertPool()
 		if !rootCAs.AppendCertsFromPEM(k8sCertPEM) {
-			log.Fatalf("No CA found for the API server")
+			klog.Fatal("No CA found for the API server")
 		}
 		tlsConfig := oscrypto.SecureTLSConfig(&tls.Config{
 			RootCAs: rootCAs,
@@ -310,7 +311,7 @@ func main() {
 
 		bearerToken, err := ioutil.ReadFile(k8sInClusterBearerToken)
 		if err != nil {
-			log.Fatalf("failed to read bearer token: %v", err)
+			klog.Fatalf("failed to read bearer token: %v", err)
 		}
 
 		srv.K8sProxyConfig = &proxy.Config{
@@ -325,11 +326,11 @@ func main() {
 		if *fServiceCAFile != "" {
 			serviceCertPEM, err := ioutil.ReadFile(*fServiceCAFile)
 			if err != nil {
-				log.Fatalf("failed to read service-ca.crt file: %v", err)
+				klog.Fatalf("failed to read service-ca.crt file: %v", err)
 			}
 			serviceProxyRootCAs := x509.NewCertPool()
 			if !serviceProxyRootCAs.AppendCertsFromPEM(serviceCertPEM) {
-				log.Fatalf("no CA found for Kubernetes services")
+				klog.Fatal("no CA found for Kubernetes services")
 			}
 			serviceProxyTLSConfig := oscrypto.SecureTLSConfig(&tls.Config{
 				RootCAs: serviceProxyRootCAs,
@@ -365,6 +366,7 @@ func main() {
 				Endpoint:        &url.URL{Scheme: "https", Host: openshiftMeteringHost, Path: "/api"},
 			}
 			srv.TerminalProxyTLSConfig = serviceProxyTLSConfig
+			srv.PluginsProxyTLSConfig = serviceProxyTLSConfig
 
 			srv.GitOpsProxyConfig = &proxy.Config{
 				TLSClientConfig: serviceProxyTLSConfig,
@@ -430,6 +432,7 @@ func main() {
 		}
 
 		srv.TerminalProxyTLSConfig = serviceProxyTLSConfig
+		srv.PluginsProxyTLSConfig = serviceProxyTLSConfig
 
 		if *fK8sModeOffClusterGitOps != "" {
 			offClusterGitOpsURL := bridge.ValidateFlagIsURL("k8s-mode-off-cluster-gitops", *fK8sModeOffClusterGitOps)
@@ -502,7 +505,7 @@ func main() {
 		if *fUserAuthOIDCClientSecretFile != "" {
 			buf, err := ioutil.ReadFile(*fUserAuthOIDCClientSecretFile)
 			if err != nil {
-				log.Fatalf("Failed to read client secret file: %v", err)
+				klog.Fatalf("Failed to read client secret file: %v", err)
 			}
 			oidcClientSecret = string(buf)
 		}
@@ -545,37 +548,36 @@ func main() {
 		}
 
 		if srv.Auther, err = auth.NewAuthenticator(context.Background(), oidcClientConfig); err != nil {
-			log.Fatalf("Error initializing authenticator: %v", err)
+			klog.Fatalf("Error initializing authenticator: %v", err)
 		}
 	case "disabled":
-		log.Warningf("running with AUTHENTICATION DISABLED!")
+		klog.Warning("running with AUTHENTICATION DISABLED!")
 	default:
 		bridge.FlagFatalf("user-auth", "must be one of: oidc, openshift, disabled")
 	}
 
-	var resourceListerToken string
 	switch *fK8sAuth {
 	case "service-account":
 		bridge.ValidateFlagIs("k8s-mode", *fK8sMode, "in-cluster")
 		srv.StaticUser = &auth.User{
 			Token: k8sAuthServiceAccountBearerToken,
 		}
-		resourceListerToken = k8sAuthServiceAccountBearerToken
+		srv.ServiceAccountToken = k8sAuthServiceAccountBearerToken
 	case "bearer-token":
 		bridge.ValidateFlagNotEmpty("k8s-auth-bearer-token", *fK8sAuthBearerToken)
 		srv.StaticUser = &auth.User{
 			Token: *fK8sAuthBearerToken,
 		}
-		resourceListerToken = *fK8sAuthBearerToken
+		srv.ServiceAccountToken = *fK8sAuthBearerToken
 	case "oidc", "openshift":
 		bridge.ValidateFlagIs("user-auth", *fUserAuth, "oidc", "openshift")
-		resourceListerToken = k8sAuthServiceAccountBearerToken
+		srv.ServiceAccountToken = k8sAuthServiceAccountBearerToken
 	default:
 		bridge.FlagFatalf("k8s-mode", "must be one of: service-account, bearer-token, oidc, openshift")
 	}
 
 	srv.MonitoringDashboardConfigMapLister = server.NewResourceLister(
-		resourceListerToken,
+		srv.ServiceAccountToken,
 		&url.URL{
 			Scheme: k8sEndpoint.Scheme,
 			Host:   k8sEndpoint.Host,
@@ -593,7 +595,7 @@ func main() {
 	)
 
 	srv.KnativeEventSourceCRDLister = server.NewResourceLister(
-		resourceListerToken,
+		srv.ServiceAccountToken,
 		&url.URL{
 			Scheme: k8sEndpoint.Scheme,
 			Host:   k8sEndpoint.Host,
@@ -611,7 +613,7 @@ func main() {
 	)
 
 	srv.KnativeChannelCRDLister = server.NewResourceLister(
-		resourceListerToken,
+		srv.ServiceAccountToken,
 		&url.URL{
 			Scheme: k8sEndpoint.Scheme,
 			Host:   k8sEndpoint.Host,
@@ -660,17 +662,17 @@ func main() {
 				http.Redirect(res, req, redirectURL.String(), http.StatusMovedPermanently)
 			})
 			redirectPort := fmt.Sprintf(":%d", *fRedirectPort)
-			log.Infof("Listening on %q for custom hostname redirect...", redirectPort)
-			log.Fatal(http.ListenAndServe(redirectPort, redirectServer))
+			klog.Infof("Listening on %q for custom hostname redirect...", redirectPort)
+			klog.Fatal(http.ListenAndServe(redirectPort, redirectServer))
 		}()
 	}
 
-	log.Infof("Binding to %s...", httpsrv.Addr)
+	klog.Infof("Binding to %s...", httpsrv.Addr)
 	if listenURL.Scheme == "https" {
-		log.Info("using TLS")
-		log.Fatal(httpsrv.ListenAndServeTLS(*fTlSCertFile, *fTlSKeyFile))
+		klog.Info("using TLS")
+		klog.Fatal(httpsrv.ListenAndServeTLS(*fTlSCertFile, *fTlSKeyFile))
 	} else {
-		log.Info("not using TLS")
-		log.Fatal(httpsrv.ListenAndServe())
+		klog.Info("not using TLS")
+		klog.Fatal(httpsrv.ListenAndServe())
 	}
 }
