@@ -54,8 +54,8 @@ export const clickTab = async (name: string) => {
 export const labelsForRow = (name: string) => rowForName(name).$$('.co-m-label');
 export const textFilter = $('[data-test-id="item-filter"]');
 export const actions = Object.freeze({
-  labels: 'Edit Labels',
-  annotations: 'Edit Annotations',
+  labels: 'Edit labels',
+  annotations: 'Edit annotations',
   edit: 'Edit',
   delete: 'Delete',
 });
@@ -68,14 +68,10 @@ export const filterForName = async (name: string) => {
 };
 
 const actionOnKind = (action: string, kind: string) => {
-  const humanizedKind = (kind.includes('~') ? kind.split('~')[2] : kind)
-    .split(/(?=[A-Z])/)
-    .join(' ');
-
-  return `${action} ${humanizedKind}`;
+  return `${action} ${kind}`;
 };
-export const editHumanizedKind = (kind: string) => actionOnKind(actions.edit, kind);
-export const deleteHumanizedKind = (kind: string) => actionOnKind(actions.delete, kind);
+export const editKind = (kind: string) => actionOnKind(actions.edit, kind);
+export const deleteKind = (kind: string) => actionOnKind(actions.delete, kind);
 
 export const clickCreateWithYAML = async () => {
   await browser.wait(until.elementToBeClickable(createYAMLButton));
@@ -96,7 +92,7 @@ export const clickKebabAction = async (resourceName: string, actionLabel: string
  * Edit row from a list.
  */
 export const editRow = (kind: string) => (name: string) =>
-  clickKebabAction(name, editHumanizedKind(kind)).then(async () => {
+  clickKebabAction(name, editKind(kind)).then(async () => {
     await browser.wait(until.presenceOf(cancelBtn));
     const reloadBtnIsPresent = await reloadBtn.isPresent();
     if (reloadBtnIsPresent) {
@@ -109,8 +105,9 @@ export const editRow = (kind: string) => (name: string) =>
 /**
  * Deletes a row from a list. Does not wait until the row is no longer visible.
  */
-export const deleteRow = (kind: string) => (name: string) =>
-  clickKebabAction(name, deleteHumanizedKind(kind)).then(async () => {
+export const deleteRow = (kind: string) => (name: string) => {
+  const label = `${actions.delete} ${kind}`;
+  return clickKebabAction(name, label).then(async () => {
     switch (kind) {
       case 'Namespace':
         await browser.wait(until.presenceOf($('input[placeholder="Enter name"]')));
@@ -130,6 +127,7 @@ export const deleteRow = (kind: string) => (name: string) =>
     const rowIsGone = until.not(until.presenceOf(rowForName(name).$('.co-kebab')));
     return browser.wait(until.or(kebabIsDisabled, until.or(listIsEmpty, rowIsGone)));
   });
+};
 
 export const rowFiltersButton = $('[data-test-id="filter-dropdown-toggle"]');
 export const rowFiltersPresent = () => browser.wait(until.presenceOf(rowFiltersButton));
@@ -146,9 +144,6 @@ export const resourceTitle = $('[data-test-id="resource-title"]');
 
 export const nameFilter = $('.pf-c-form-control.co-text-filter');
 export const messageLbl = $('.cos-status-box');
-export const modalAnnotationsLink = $(
-  '[data-test-id=resource-summary] [data-test-id=edit-annotations]',
-);
 
 export const visitResource = async (resource: string, name: string) => {
   await browser.get(`${appHost}/k8s/ns/${testName}/${resource}/${name}`);
@@ -166,7 +161,7 @@ export const clickDetailsPageAction = async (actionID: string) => {
 export const deleteResource = async (resource: string, kind: string, name: string) => {
   await visitResource(resource, name);
   await isLoaded();
-  clickDetailsPageAction(deleteHumanizedKind(kind));
+  clickDetailsPageAction(deleteKind(kind));
   await browser.wait(until.presenceOf($('#confirm-action')));
   await $('#confirm-action').click();
 };
