@@ -1,9 +1,10 @@
 import * as React from 'react';
+import { useTranslation } from 'react-i18next';
 import { Grid, GridItem } from '@patternfly/react-core';
 import { Humanize } from '@console/internal/components/utils';
 import { K8sKind } from '@console/internal/module/k8s';
 import { addAvailable, StackDataPoint, getLegends } from './utils';
-import { BreakdownChart } from './breakdown-chart';
+import { BreakdownChart, LabelPadding } from './breakdown-chart';
 import { BreakdownChartLoading } from './breakdown-loading';
 import { TotalCapacityBody } from './breakdown-capacity';
 
@@ -17,21 +18,29 @@ export const BreakdownCardBody: React.FC<BreakdownBodyProps> = ({
   isLoading,
   hasLoadError,
   ocsVersion = '',
+  labelPadding,
 }) => {
+  const { t } = useTranslation();
+
   if (isLoading && !hasLoadError) {
     return <BreakdownChartLoading />;
   }
   if (!capacityUsed || !top5MetricsStats.length || hasLoadError) {
-    return <div className="text-secondary">Not available</div>;
+    return (
+      <div className="text-secondary capacity-breakdown-card--error">
+        {t('dashboard~Not available')}
+      </div>
+    );
   }
   if (capacityUsed === '0') {
-    return <div className="text-secondary">Not enough usage data</div>;
+    return (
+      <div className="text-secondary capacity-breakdown-card--error">
+        {t('ceph-storage-plugin~Not enough usage data')}
+      </div>
+    );
   }
 
-  const usedCapacity = `${humanize(capacityUsed).string} used`;
-  const availableCapacity = `${humanize(capacityAvailable).string} available`;
-
-  const chartData = addAvailable(top5MetricsStats, capacityAvailable, metricTotal, humanize);
+  const chartData = addAvailable(top5MetricsStats, capacityAvailable, metricTotal, humanize, t);
 
   const legends = getLegends(chartData);
 
@@ -43,13 +52,17 @@ export const BreakdownCardBody: React.FC<BreakdownBodyProps> = ({
   return (
     <Grid>
       <GridItem span={4}>
-        <TotalCapacityBody value={usedCapacity} />
+        <TotalCapacityBody
+          capacity={humanize(capacityUsed).string}
+          suffix={t('ceph-storage-plugin~used')}
+        />
       </GridItem>
       <GridItem span={4} />
       <GridItem span={4}>
         {capacityAvailable && (
           <TotalCapacityBody
-            value={availableCapacity}
+            capacity={humanize(capacityAvailable).string}
+            suffix={t('ceph-storage-plugin~available')}
             className="capacity-breakdown-card__available-body text-secondary"
           />
         )}
@@ -60,6 +73,7 @@ export const BreakdownCardBody: React.FC<BreakdownBodyProps> = ({
           legends={legends}
           metricModel={metricModel}
           ocsVersion={ocsVersion}
+          labelPadding={labelPadding}
         />
       </GridItem>
     </Grid>
@@ -76,4 +90,5 @@ export type BreakdownBodyProps = {
   metricModel: K8sKind;
   humanize: Humanize;
   ocsVersion?: string;
+  labelPadding?: LabelPadding;
 };
