@@ -1,4 +1,5 @@
 import * as React from 'react';
+import { Trans, useTranslation } from 'react-i18next';
 import * as classNames from 'classnames';
 import { FieldLevelHelp, humanizeBinaryBytes } from '@console/internal/components/utils/index';
 import {
@@ -13,21 +14,28 @@ import { getName, getRequestedPVCSize } from '@console/shared';
 import { OCSServiceModel } from '../../../models';
 import { getCurrentDeviceSetIndex } from '../../../utils/add-capacity';
 import { OSD_CAPACITY_SIZES } from '../../../utils/osd-size-dropdown';
-import { NO_PROVISIONER, OCS_DEVICE_SET_REPLICA } from '../../../constants';
 import {
-  labelTooltip,
+  NO_PROVISIONER,
+  OCS_DEVICE_SET_ARBITER_REPLICA,
+  OCS_DEVICE_SET_REPLICA,
+} from '../../../constants';
+import {
+  requestedCapacityTooltip,
   storageClassTooltip,
   defaultRequestSize,
 } from '../../../constants/ocs-install';
 import { OCSStorageClassDropdown } from '../storage-class-dropdown';
 import { PVsAvailableCapacity } from '../../ocs-install/pvs-available-capacity';
-import { createDeviceSet, DeviceSet } from '../../ocs-install/ocs-request-data';
+import { createDeviceSet } from '../../ocs-install/ocs-request-data';
 import { cephCapacityResource } from '../../../constants/resources';
+import { DeviceSet } from '../../../types';
 import './_add-capacity-modal.scss';
 
 const getProvisionedCapacity = (value: number) => (value % 1 ? (value * 3).toFixed(2) : value * 3);
 
 export const AddCapacityModal = (props: AddCapacityModalProps) => {
+  const { t } = useTranslation();
+
   const { ocsConfig, close, cancel } = props;
   const deviceSets: DeviceSet[] = ocsConfig?.spec.storageDeviceSets || [];
 
@@ -41,12 +49,15 @@ export const AddCapacityModal = (props: AddCapacityModalProps) => {
 
   const cephCapacity: string = response?.data?.result?.[0]?.value[1];
   const osdSizeWithUnit = getRequestedPVCSize(deviceSets[0].dataPVCTemplate);
-  const osdSizeWithoutUnit: number = OSD_CAPACITY_SIZES[osdSizeWithUnit]?.size;
+  const osdSizeWithoutUnit: number = OSD_CAPACITY_SIZES[osdSizeWithUnit];
   const provisionedCapacity = getProvisionedCapacity(osdSizeWithoutUnit);
   const isNoProvionerSC: boolean = storageClass?.provisioner === NO_PROVISIONER;
   const selectedSCName: string = getName(storageClass);
   const deviceSetIndex: number = getCurrentDeviceSetIndex(deviceSets, selectedSCName);
-  const replica = OCS_DEVICE_SET_REPLICA;
+  const hasFlexibleScaling = ocsConfig?.spec?.flexibleScaling;
+  const isArbiterEnabled: boolean = ocsConfig?.spec?.arbiter?.enable;
+  const replica = isArbiterEnabled ? OCS_DEVICE_SET_ARBITER_REPLICA : OCS_DEVICE_SET_REPLICA;
+  const name = getName(ocsConfig);
 
   let currentCapacity: React.ReactNode;
 
@@ -55,7 +66,7 @@ export const AddCapacityModal = (props: AddCapacityModalProps) => {
       <div className="skeleton-text ceph-add-capacity__current-capacity--loading" />
     );
   } else if (loadError || !cephCapacity || !osdSizeWithoutUnit || deviceSetIndex === -1) {
-    currentCapacity = <div className="text-muted">Not available</div>;
+    currentCapacity = <div className="text-muted">{t('ceph-storage-plugin~Not available')}</div>;
   } else {
     currentCapacity = (
       <div className="text-muted">
@@ -76,20 +87,34 @@ export const AddCapacityModal = (props: AddCapacityModalProps) => {
       path: '',
       value: null,
     };
-    const portable = !isNoProvionerSC;
     const osdSize = isNoProvionerSC ? defaultRequestSize.BAREMETAL : osdSizeWithUnit;
+    let portable = !isNoProvionerSC;
+    let deviceSetReplica = replica;
+    let deviceSetCount = 1;
+
     if (deviceSetIndex === -1) {
+      if (hasFlexibleScaling) {
+        portable = false;
+        deviceSetReplica = 1;
+      }
       patch.op = 'add';
       patch.path = `/spec/storageDeviceSets/-`;
-      patch.value = createDeviceSet(selectedSCName, osdSize, portable);
+      patch.value = createDeviceSet(
+        selectedSCName,
+        osdSize,
+        portable,
+        deviceSetReplica,
+        deviceSetCount,
+      );
     } else {
+      if (hasFlexibleScaling) deviceSetCount = 3;
       patch.op = 'replace';
       patch.path = `/spec/storageDeviceSets/${deviceSetIndex}/count`;
-      patch.value = deviceSets[deviceSetIndex].count + 1;
+      patch.value = deviceSets[deviceSetIndex].count + deviceSetCount;
     }
 
     if (!selectedSCName) {
-      setError('No StorageClass selected');
+      setError(t('ceph-storage-plugin~No StorageClass selected'));
       setProgress(false);
     } else {
       k8sPatch(OCSServiceModel, ocsConfig, [patch])
@@ -106,9 +131,11 @@ export const AddCapacityModal = (props: AddCapacityModalProps) => {
 
   return (
     <form onSubmit={submit} className="modal-content modal-content--no-inner-scroll">
-      <ModalTitle>Add Capacity</ModalTitle>
+      <ModalTitle>{t('ceph-storage-plugin~Add Capacity')}</ModalTitle>
       <ModalBody>
-        Adding capacity for <strong>{getName(ocsConfig)}</strong>, may increase your expenses.
+        <Trans t={t} ns="ceph-storage-plugin" values={{ name }}>
+          Adding capacity for <strong>{{ name }}</strong>, may increase your expenses.
+        </Trans>
         <div className="ceph-add-capacity__modal">
           <div
             className={classNames('ceph-add-capacity__sc-dropdown', {
@@ -116,10 +143,10 @@ export const AddCapacityModal = (props: AddCapacityModalProps) => {
             })}
           >
             <label className="control-label" htmlFor="storageClass">
-              Storage Class
-              <FieldLevelHelp>{storageClassTooltip}</FieldLevelHelp>
+              {t('ceph-storage-plugin~Storage Class')}
+              <FieldLevelHelp>{storageClassTooltip(t)}</FieldLevelHelp>
             </label>
-            <OCSStorageClassDropdown onChange={onChange} />
+            <OCSStorageClassDropdown onChange={onChange} data-test="add-cap-sc-dropdown" />
           </div>
           {isNoProvionerSC ? (
             <PVsAvailableCapacity
@@ -130,8 +157,8 @@ export const AddCapacityModal = (props: AddCapacityModalProps) => {
           ) : (
             <div>
               <label className="control-label" htmlFor="requestSize">
-                Raw Capacity
-                <FieldLevelHelp>{labelTooltip}</FieldLevelHelp>
+                {t('ceph-storage-plugin~Raw Capacity')}
+                <FieldLevelHelp>{requestedCapacityTooltip}</FieldLevelHelp>
               </label>
               <div className="ceph-add-capacity__form">
                 <input
@@ -145,13 +172,14 @@ export const AddCapacityModal = (props: AddCapacityModalProps) => {
                 />
                 {provisionedCapacity && (
                   <div className="ceph-add-capacity__input--info-text">
-                    x {replica} replicas = <strong>{provisionedCapacity} TiB</strong>
+                    {t('ceph-storage-plugin~x {{ replica, number }} replicas =', { replica })}{' '}
+                    <strong data-test="provisioned-capacity">{provisionedCapacity} TiB</strong>
                   </div>
                 )}
               </div>
               <div className="ceph-add-capacity__current-capacity">
                 <div className="text-secondary ceph-add-capacity__current-capacity--text">
-                  <strong>Currently Used:</strong>
+                  <strong>{t('ceph-storage-plugin~Currently Used:')}</strong>
                 </div>
                 {currentCapacity}
               </div>
@@ -162,7 +190,7 @@ export const AddCapacityModal = (props: AddCapacityModalProps) => {
       <ModalSubmitFooter
         inProgress={inProgress}
         errorMessage={errorMessage}
-        submitText="Add"
+        submitText={t('ceph-storage-plugin~Add')}
         cancel={cancel}
       />
     </form>
