@@ -2,7 +2,6 @@ import * as React from 'react';
 import * as _ from 'lodash';
 import * as classNames from 'classnames';
 import { match } from 'react-router-dom';
-import { connect } from 'react-redux';
 import { sortable } from '@patternfly/react-table';
 import { JSONSchema6 } from 'json-schema';
 import { Status, SuccessStatus, getBadgeFromType } from '@console/shared';
@@ -41,7 +40,6 @@ import {
   apiGroupForReference,
   apiVersionForReference,
   kindForReference,
-  modelFor,
   referenceFor,
   referenceForModel,
   nameForModel,
@@ -50,13 +48,11 @@ import {
 } from '@console/internal/module/k8s';
 import { ResourceEventStream } from '@console/internal/components/events';
 import { deleteModal } from '@console/internal/components/modals';
-import { RootState } from '@console/internal/redux';
 import { ClusterServiceVersionModel } from '../../models';
 import { ClusterServiceVersionKind } from '../../types';
-import { isInternalObject, getInternalAPIReferences, getInternalObjects } from '../../utils';
 import { DescriptorType, StatusCapability, StatusDescriptor } from '../descriptors/types';
 import { Resources } from '../k8s-resource';
-import { referenceForProvidedAPI } from '../index';
+import { providedAPIsForCSV, referenceForProvidedAPI } from '../index';
 import { csvNameFromWindow, OperandLink } from './operand-link';
 import ErrorAlert from '@console/shared/src/components/alerts/error';
 import {
@@ -66,7 +62,9 @@ import {
 } from '@console/plugin-sdk';
 import { CustomResourceDefinitionModel } from '@console/internal/models';
 import { useK8sModel } from '@console/shared/src/hooks/useK8sModel';
+import { useK8sModels } from '@console/shared/src/hooks/useK8sModels';
 import { DescriptorDetailsItem, DescriptorDetailsItemList } from '../descriptors';
+import { useTranslation } from 'react-i18next';
 
 export const getOperandActions = (
   ref: K8sResourceKindReference,
@@ -91,7 +89,9 @@ export const getOperandActions = (
             csvNameFromWindow()}/${reference}/${obj.metadata.name}/yaml`
         : `/k8s/cluster/${reference}/${obj.metadata.name}/yaml`;
       return {
-        label: `Edit ${kind.label}`,
+        // t('olm~Edit {{item}}')
+        labelKey: 'olm~Edit {{item}}',
+        labelKind: { item: kind.label },
         href,
         accessReview: {
           group: kind.apiGroup,
@@ -102,9 +102,10 @@ export const getOperandActions = (
         },
       };
     },
-
     (kind, obj) => ({
-      label: `Delete ${kind.label}`,
+      // t('olm~Delete {{item}}')
+      labelKey: 'olm~Delete {{item}}',
+      labelKind: { item: kind.label },
       callback: () =>
         deleteModal({
           kind,
@@ -134,50 +135,6 @@ const tableColumnClasses = [
   Kebab.columnClass,
 ];
 
-export const OperandTableHeader = () => {
-  return [
-    {
-      title: 'Name',
-      sortField: 'metadata.name',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[0] },
-    },
-    {
-      title: 'Kind',
-      sortField: 'kind',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[1] },
-    },
-    {
-      title: 'Status',
-      sortFunc: 'operandStatus',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[2] },
-    },
-    {
-      title: 'Labels',
-      sortField: 'metadata.labels',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[3] },
-    },
-    {
-      title: 'Last Updated',
-      sortField: 'metadata.creationTimestamp',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[4] },
-    },
-    {
-      title: '',
-      props: { className: tableColumnClasses[5] },
-    },
-  ];
-};
-
-type OperandStatusType = {
-  type: string;
-  value: string;
-};
-
 const getOperandStatus = (obj: K8sResourceKind): OperandStatusType => {
   const { phase, status, state, conditions } = obj?.status || {};
 
@@ -214,7 +171,7 @@ const getOperandStatus = (obj: K8sResourceKind): OperandStatusType => {
   return null;
 };
 
-export const OperandStatus: React.FunctionComponent<OperandStatusProps> = ({ operand }) => {
+export const OperandStatus: React.FC<OperandStatusProps> = ({ operand }) => {
   const status: OperandStatusType = getOperandStatus(operand);
   if (!status) {
     return <>-</>;
@@ -228,7 +185,7 @@ export const OperandStatus: React.FunctionComponent<OperandStatusProps> = ({ ope
   );
 };
 
-const getOperandStatusText = (operand: K8sResourceKind) => {
+const getOperandStatusText = (operand: K8sResourceKind): string => {
   const status = getOperandStatus(operand);
   return status ? `${status.type}: ${status.value}` : '';
 };
@@ -270,6 +227,45 @@ export const OperandTableRow: React.FC<OperandTableRowProps> = ({ obj, index, ro
 };
 
 export const OperandList: React.FC<OperandListProps> = (props) => {
+  const { t } = useTranslation();
+  const Header = () => {
+    return [
+      {
+        title: t('public~Name'),
+        sortField: 'metadata.name',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[0] },
+      },
+      {
+        title: t('public~Kind'),
+        sortField: 'kind',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[1] },
+      },
+      {
+        title: t('public~Status'),
+        sortFunc: 'operandStatus',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[2] },
+      },
+      {
+        title: t('public~Labels'),
+        sortField: 'metadata.labels',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[3] },
+      },
+      {
+        title: t('public~Last updated'),
+        sortField: 'metadata.creationTimestamp',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[4] },
+      },
+      {
+        title: '',
+        props: { className: tableColumnClasses[5] },
+      },
+    ];
+  };
   const Row = React.useCallback(
     (rowArgs: RowFunctionArgs<K8sResourceKind>) => (
       <OperandTableRow
@@ -281,22 +277,27 @@ export const OperandList: React.FC<OperandListProps> = (props) => {
     ),
     [],
   );
-  const ensureKind = (data: K8sResourceKind[]) =>
-    data.map((obj) => {
-      if (obj.apiVersion && obj.kind) {
-        return obj;
-      }
-      const reference = props.kinds[0];
-      return {
-        apiVersion: apiVersionForReference(reference),
-        kind: kindForReference(reference),
-        ...obj,
-      };
-    });
+  const data = React.useMemo(
+    () =>
+      props.data?.map?.((obj) => {
+        if (obj.apiVersion && obj.kind) {
+          return obj;
+        }
+        const reference = props.kinds[0];
+        return {
+          apiVersion: apiVersionForReference(reference),
+          kind: kindForReference(reference),
+          ...obj,
+        };
+      }) ?? [],
+    [props.data, props.kinds],
+  );
   const EmptyMsg = () => (
     <MsgBox
-      title="No Operands Found"
-      detail="Operands are declarative components used to define the behavior of the application."
+      title={t('olm~No operands found')}
+      detail={t(
+        'olm~Operands are declarative components used to define the behavior of the application.',
+      )}
     />
   );
 
@@ -306,70 +307,65 @@ export const OperandList: React.FC<OperandListProps> = (props) => {
       customSorts={{
         operandStatus: getOperandStatusText,
       }}
-      data={ensureKind(props.data)}
+      data={data}
       EmptyMsg={EmptyMsg}
       aria-label="Operands"
-      Header={OperandTableHeader}
+      Header={Header}
       Row={Row}
       virtualize
     />
   );
 };
 
-const inFlightStateToProps = ({ k8s }: RootState) => ({
-  inFlight: k8s.getIn(['RESOURCES', 'inFlight']),
-});
-
-export const ProvidedAPIsPage = connect(inFlightStateToProps)((props: ProvidedAPIsPageProps) => {
+export const ProvidedAPIsPage = (props: ProvidedAPIsPageProps) => {
+  const { t } = useTranslation();
   const { obj } = props;
-  const { owned = [] } = obj.spec.customresourcedefinitions;
-  const internalObjects = getInternalObjects(obj);
-  const internalAPIs = getInternalAPIReferences(obj);
-  const firehoseResources = owned.reduce((resources, desc) => {
-    const reference = referenceForProvidedAPI(desc);
-    const model = modelFor(reference);
-    return model && !internalAPIs.some((api) => api === reference)
+  const [models, inFlight] = useK8sModels();
+  if (inFlight) {
+    return null;
+  }
+  const providedAPIs = providedAPIsForCSV(obj);
+
+  // Exclude provided APIs that do not have a model
+  const firehoseResources = providedAPIs.reduce((resourceAccumulator, api) => {
+    const reference = referenceForProvidedAPI(api);
+    const model = models?.[reference];
+    return model
       ? [
-          ...resources,
+          ...resourceAccumulator,
           {
-            kind: referenceForProvidedAPI(desc),
+            kind: referenceForProvidedAPI(api),
             namespaced: model.namespaced,
-            prop: desc.kind,
+            prop: api.kind,
           },
         ]
-      : resources;
+      : resourceAccumulator;
   }, []);
 
   const EmptyMsg = () => (
     <MsgBox
-      title="No Provided APIs Defined"
-      detail="This application was not properly installed or configured."
+      title={t('olm~No provided APIs defined')}
+      detail={t('olm~This application was not properly installed or configured.')}
     />
   );
   const createLink = (name: string) =>
     `/k8s/ns/${obj.metadata.namespace}/${ClusterServiceVersionModel.plural}/${
       obj.metadata.name
-    }/${referenceForProvidedAPI(_.find(owned, { name }))}/~new`;
+    }/${referenceForProvidedAPI(_.find(providedAPIs, { name }))}/~new`;
   const createProps =
-    owned.length > 1
+    providedAPIs.length > 1
       ? {
-          items: owned.reduce(
-            (acc, crd) =>
-              !isInternalObject(internalObjects, crd.name)
-                ? { ...acc, [crd.name]: crd.displayName }
-                : acc,
-            {},
-          ),
+          items: providedAPIs.reduce((acc, api) => ({ ...acc, [api.name]: api.displayName }), {}),
           createLink,
         }
-      : { to: owned.length === 1 ? createLink(owned[0].name) : null };
+      : { to: providedAPIs.length === 1 ? createLink(providedAPIs[0].name) : null };
 
   const owners = (ownerRefs: OwnerReference[], items: K8sResourceKind[]) =>
     ownerRefs.filter(({ uid }) => items.filter(({ metadata }) => metadata.uid === uid).length > 0);
   const flatten = (resources: { [kind: string]: { data: K8sResourceKind[] } }) =>
     _.flatMap(resources, (resource) => _.map(resource.data, (item) => item)).filter(
       ({ kind, metadata }, i, allResources) =>
-        owned.filter((item) => item.kind === kind).length > 0 ||
+        providedAPIs.filter((item) => item.kind === kind).length > 0 ||
         owners(metadata.ownerReferences || [], allResources).length > 0,
     );
 
@@ -385,39 +381,42 @@ export const ProvidedAPIsPage = connect(inFlightStateToProps)((props: ProvidedAP
     },
   ];
 
-  if (props.inFlight) {
-    return null;
-  }
-
   return firehoseResources.length > 0 ? (
     <MultiListPage
       {...props}
       ListComponent={OperandList}
-      filterLabel="Resources by name"
+      filterLabel={t('olm~Resources by name')}
       resources={firehoseResources}
       namespace={obj.metadata.namespace}
-      canCreate={owned.length > 0}
+      canCreate={providedAPIs.length > 0}
       createProps={createProps}
-      createButtonText={owned.length > 1 ? 'Create New' : `Create ${owned[0].displayName}`}
+      createButtonText={
+        providedAPIs.length > 1
+          ? t('olm~Create new')
+          : t('olm~Create {{item}}', {
+              item: providedAPIs[0].displayName,
+            })
+      }
       flatten={flatten}
       rowFilters={firehoseResources.length > 1 ? rowFilters : null}
     />
   ) : (
     <StatusBox loaded EmptyMsg={EmptyMsg} />
   );
-});
+};
 
 export const ProvidedAPIPage = connectToModel((props: ProvidedAPIPageProps) => {
+  const { t } = useTranslation();
   const { namespace, kind, kindsInFlight, kindObj, csv } = props;
-
   if (!kindObj) {
     return kindsInFlight ? (
       <LoadingBox />
     ) : (
       <ErrorPage404
-        message={`The server doesn't have a resource type ${kindForReference(
-          kind,
-        )}. Try refreshing the page if it was recently added.`}
+        message={t(
+          "olm~The server doesn't have a resource type {{kind}}. Try refreshing the page if it was recently added.",
+          { kind: kindForReference(kind) },
+        )}
       />
     );
   }
@@ -427,7 +426,7 @@ export const ProvidedAPIPage = connectToModel((props: ProvidedAPIPageProps) => {
     <ListPage
       kind={kind}
       ListComponent={OperandList}
-      canCreate={_.get(kindObj, 'verbs', [] as string[]).some((v) => v === 'create')}
+      canCreate={kindObj?.verbs?.includes('create')}
       createProps={{ to }}
       namespace={kindObj.namespaced ? namespace : null}
       badge={getBadgeFromType(kindObj.badge)}
@@ -459,6 +458,7 @@ const PodStatuses: React.FC<PodStatusesProps> = ({ kindObj, obj, podStatusDescri
   ) : null;
 
 export const OperandDetails = connectToModel(({ crd, csv, kindObj, obj }: OperandDetailsProps) => {
+  const { t } = useTranslation();
   const { kind, status } = obj;
   const [errorMessage, setErrorMessage] = React.useState(null);
   const handleError = (err: Error) => setErrorMessage(err.message);
@@ -506,7 +506,7 @@ export const OperandDetails = connectToModel(({ crd, csv, kindObj, obj }: Operan
     <div className="co-operand-details co-m-pane">
       <div className="co-m-pane__body">
         {errorMessage && <ErrorAlert message={errorMessage} />}
-        <SectionHeading text={`${displayName || kind} Overview`} />
+        <SectionHeading text={t('olm~{{kind}} overview', { kind: displayName || kind })} />
         <PodStatuses
           kindObj={kindObj}
           obj={obj}
@@ -574,6 +574,7 @@ const ResourcesTab = (resourceProps) => (
 );
 
 export const OperandDetailsPage = (props: OperandDetailsPageProps) => {
+  const { t } = useTranslation();
   const [model] = useK8sModel(props.match.params.plural);
   const actionExtensions = useExtensions<ClusterServiceVersionAction>(
     isClusterServiceVersionAction,
@@ -606,7 +607,7 @@ export const OperandDetailsPage = (props: OperandDetailsPageProps) => {
       menuActions={menuActions}
       breadcrumbsFor={() => [
         {
-          name: 'Installed Operators',
+          name: t('olm~Installed Operators'),
           path: `/k8s/ns/${props.match.params.ns}/${ClusterServiceVersionModel.plural}`,
         },
         {
@@ -614,7 +615,7 @@ export const OperandDetailsPage = (props: OperandDetailsPageProps) => {
           path: props.match.url.slice(0, props.match.url.lastIndexOf('/')),
         },
         {
-          name: `${kindForReference(props.match.params.plural)} Details`, // Use url param in case model doesn't exist
+          name: t('olm~{{item}} details', { item: kindForReference(props.match.params.plural) }), // Use url param in case model doesn't exist
           path: `${props.match.url}`,
         },
       ]}
@@ -634,6 +635,11 @@ export const OperandDetailsPage = (props: OperandDetailsPageProps) => {
   );
 };
 
+type OperandStatusType = {
+  type: string;
+  value: string;
+};
+
 export type OperandListProps = {
   loaded: boolean;
   kinds?: GroupVersionKind[];
@@ -716,6 +722,5 @@ OperandList.displayName = 'OperandList';
 ProvidedAPIsPage.displayName = 'ProvidedAPIsPage';
 OperandDetailsPage.displayName = 'OperandDetailsPage';
 OperandTableRow.displayName = 'OperandTableRow';
-OperandTableHeader.displayName = 'OperandTableHeader';
 OperandDetailsSection.displayName = 'OperandDetailsSection';
 PodStatuses.displayName = 'PodStatuses';
