@@ -1,5 +1,7 @@
 import * as _ from 'lodash';
 import * as React from 'react';
+import { useTranslation } from 'react-i18next';
+import i18next from 'i18next';
 import { connect } from 'react-redux';
 import { Link } from 'react-router-dom';
 import {
@@ -10,7 +12,8 @@ import {
 } from '@console/patternfly';
 import * as UIActions from '@console/internal/actions/ui';
 import store, { RootState } from '@console/internal/redux';
-import { Alert, alertURL } from '@console/internal/components/monitoring';
+import { Alert, PrometheusRulesResponse } from '@console/internal/components/monitoring/types';
+import { getAlertsAndRules, alertURL } from '@console/internal/components/monitoring/utils';
 import { NotificationAlerts } from '@console/internal/reducers/ui';
 import { RedExclamationCircleIcon } from '@console/shared';
 import {
@@ -19,7 +22,6 @@ import {
   getAlertName,
   getAlertSeverity,
   getAlertTime,
-  getAlerts,
 } from '@console/shared/src/components/dashboard/status-card/alert-utils';
 import {
   EmptyState,
@@ -29,97 +31,159 @@ import {
   EmptyStateVariant,
   Title,
 } from '@patternfly/react-core';
+import { isAlertAction, useExtensions, AlertAction } from '@console/plugin-sdk';
+import { usePrevious } from '@console/shared/src/hooks/previous';
 
 import { coFetchJSON } from '../co-fetch';
-import { ClusterUpdate, ClusterVersionKind, referenceForModel } from '../module/k8s';
+import {
+  ClusterUpdate,
+  ClusterVersionKind,
+  getNewerClusterVersionChannel,
+  getSimilarClusterVersionChannels,
+  getSortedUpdates,
+  referenceForModel,
+  splitClusterVersionChannel,
+} from '../module/k8s';
 import { ClusterVersionModel } from '../models';
-import { getSortedUpdates } from './modals/cluster-update-modal';
-import { usePrevious } from '@console/metal3-plugin/src/hooks';
 import { useK8sWatchResource, WatchK8sResource } from './utils/k8s-watch-hook';
 import { useAccessReview } from './utils/rbac';
+import { LinkifyExternal } from './utils';
+import { PrometheusEndpoint } from './graphs/helpers';
 
 const criticalCompare = (a: Alert): boolean => getAlertSeverity(a) === 'critical';
 const otherAlertCompare = (a: Alert): boolean => getAlertSeverity(a) !== 'critical';
 
-const AlertErrorState: React.FC<AlertErrorProps> = ({ errorText }) => (
-  <EmptyState variant={EmptyStateVariant.full}>
-    <EmptyStateIcon className="co-status-card__alerts-icon" icon={RedExclamationCircleIcon} />
-    <Title headingLevel="h5" size="lg">
-      Alerts could not be loaded
-    </Title>
-    {errorText && <EmptyStateBody>{errorText}</EmptyStateBody>}
-  </EmptyState>
-);
+const AlertErrorState: React.FC<AlertErrorProps> = ({ errorText }) => {
+  const { t } = useTranslation();
+  return (
+    <EmptyState variant={EmptyStateVariant.full}>
+      <EmptyStateIcon className="co-status-card__alerts-icon" icon={RedExclamationCircleIcon} />
+      <Title headingLevel="h5" size="lg">
+        {t('notification-drawer~Alerts could not be loaded')}
+      </Title>
+      {errorText && <EmptyStateBody>{errorText}</EmptyStateBody>}
+    </EmptyState>
+  );
+};
 
-const AlertEmptyState: React.FC<AlertEmptyProps> = ({ drawerToggle }) => (
-  <EmptyState variant={EmptyStateVariant.full} className="co-status-card__alerts-msg">
-    <Title headingLevel="h5" size="lg">
-      No critical alerts
-    </Title>
-    <EmptyStateBody>
-      There are currently no critical alerts firing. There may be firing alerts of other severities
-      or silenced critical alerts however.
-    </EmptyStateBody>
-    <EmptyStateSecondaryActions>
-      <Link to="/monitoring/alerts" onClick={drawerToggle}>
-        View all alerts
-      </Link>
-    </EmptyStateSecondaryActions>
-  </EmptyState>
-);
+const AlertEmptyState: React.FC<AlertEmptyProps> = ({ drawerToggle }) => {
+  const { t } = useTranslation();
+  return (
+    <EmptyState variant={EmptyStateVariant.full} className="co-status-card__alerts-msg">
+      <Title headingLevel="h5" size="lg">
+        {t('notification-drawer~No critical alerts')}
+      </Title>
+      <EmptyStateBody>
+        {t(
+          'notification-drawer~There are currently no critical alerts firing. There may be firing alerts of other severities or silenced critical alerts however.',
+        )}
+      </EmptyStateBody>
+      <EmptyStateSecondaryActions>
+        <Link to="/monitoring/alerts" onClick={drawerToggle}>
+          {t('notification-drawer~View all alerts')}
+        </Link>
+      </EmptyStateSecondaryActions>
+    </EmptyState>
+  );
+};
 
-export const alertActions = new Map().set('AlertmanagerReceiversNotConfigured', {
-  text: 'Configure',
-  path: '/monitoring/alertmanagerconfig',
-});
+export const getAlertActions = (actionsExtensions: AlertAction[]) => {
+  const alertActions = new Map().set('AlertmanagerReceiversNotConfigured', {
+    text: i18next.t('notification-drawer~Configure'),
+    path: '/monitoring/alertmanagerconfig',
+  });
+  actionsExtensions.forEach(({ properties }) =>
+    alertActions.set(properties.alert, {
+      text: properties.text,
+      path: properties.path,
+    }),
+  );
+  return alertActions;
+};
 
 const getAlertNotificationEntries = (
   isLoaded: boolean,
   alertData: Alert[],
   toggleNotificationDrawer: () => void,
+  alertActionExtensions: AlertAction[],
   isCritical: boolean,
 ): React.ReactNode[] =>
   isLoaded && !_.isEmpty(alertData)
     ? alertData
         .filter((a) => (isCritical ? criticalCompare(a) : otherAlertCompare(a)))
         .map((alert, i) => {
-          const action = alertActions.get(alert.rule.name);
+          const action = getAlertActions(alertActionExtensions).get(alert.rule.name);
+          const alertActionPath = _.isFunction(action?.path) ? action.path(alert) : action?.path;
           return (
             <NotificationEntry
               key={`${i}_${alert.activeAt}`}
-              description={getAlertDescription(alert) || getAlertMessage(alert)}
+              description={
+                <LinkifyExternal>
+                  {getAlertDescription(alert) || getAlertMessage(alert)}
+                </LinkifyExternal>
+              }
               timestamp={getAlertTime(alert)}
               type={NotificationTypes[getAlertSeverity(alert)]}
               title={getAlertName(alert)}
               toggleNotificationDrawer={toggleNotificationDrawer}
               targetPath={alertURL(alert, alert.rule.id)}
               actionText={action?.text}
-              actionPath={action?.path}
+              actionPath={alertActionPath}
             />
           );
         })
     : [];
 
 const getUpdateNotificationEntries = (
-  isLoaded: boolean,
-  updateData: ClusterUpdate[],
+  cv: ClusterVersionKind,
   isEditable: boolean,
   toggleNotificationDrawer: () => void,
-): React.ReactNode[] =>
-  isLoaded && !_.isEmpty(updateData) && isEditable
-    ? [
-        <NotificationEntry
-          actionPath="/settings/cluster"
-          actionText="Update cluster"
-          key="cluster-udpate"
-          description={updateData[0].version || 'Unknown'}
-          type={NotificationTypes.update}
-          title="Cluster update available"
-          toggleNotificationDrawer={toggleNotificationDrawer}
-          targetPath="/settings/cluster"
-        />,
-      ]
-    : [];
+): React.ReactNode[] => {
+  if (!cv || !isEditable) {
+    return [];
+  }
+  const updateData: ClusterUpdate[] = getSortedUpdates(cv);
+  const currentChannel = cv?.spec?.channel;
+  const currentPrefix = splitClusterVersionChannel(currentChannel)?.prefix;
+  const similarChannels = getSimilarClusterVersionChannels(cv, currentPrefix);
+  const newerChannel = getNewerClusterVersionChannel(similarChannels, currentChannel);
+  const newerChannelVersion = splitClusterVersionChannel(newerChannel)?.version;
+  const entries = [];
+  if (!_.isEmpty(updateData)) {
+    entries.push(
+      <NotificationEntry
+        actionPath="/settings/cluster?showVersions"
+        actionText={i18next.t('notification-drawer~Update cluster')}
+        key="cluster-update"
+        description={updateData[0].version || i18next.t('notification-drawer~Unknown')}
+        type={NotificationTypes.update}
+        title={i18next.t('notification-drawer~Cluster update available')}
+        toggleNotificationDrawer={toggleNotificationDrawer}
+        targetPath="/settings/cluster?showVersions"
+      />,
+    );
+  }
+  if (newerChannel) {
+    entries.push(
+      <NotificationEntry
+        actionPath="/settings/cluster?showChannels"
+        actionText={i18next.t('notification-drawer~Update channel')}
+        key="channel-update"
+        description={i18next.t(
+          'notification-drawer~The {{newerChannel}} channel is available. If you are interested in updating this cluster to {{newerChannelVersion}} in the future, change the update channel to {{newerChannel}} to receive recommended updates.',
+          { newerChannel, newerChannelVersion },
+        )}
+        type={NotificationTypes.update}
+        title={i18next.t('notification-drawer~{{newerChannel}} channel available', {
+          newerChannel,
+        })}
+        toggleNotificationDrawer={toggleNotificationDrawer}
+        targetPath="/settings/cluster?showChannels"
+      />,
+    );
+  }
+  return entries;
+};
 
 const pollerTimeouts = {};
 const pollers = {};
@@ -137,16 +201,27 @@ export const refreshNotificationPollers = () => {
   _.invoke(pollers, 'notificationAlerts');
 };
 
+const getAlerts = (alertsResults: PrometheusRulesResponse): Alert[] =>
+  alertsResults
+    ? getAlertsAndRules(alertsResults.data)
+        .alerts.filter(
+          (a) =>
+            a.state === 'firing' &&
+            getAlertName(a) !== 'Watchdog' &&
+            getAlertName(a) !== 'UpdateAvailable',
+        )
+        .sort((a, b) => +new Date(getAlertTime(b)) - +new Date(getAlertTime(a)))
+    : [];
+
 export const ConnectedNotificationDrawer_: React.FC<ConnectedNotificationDrawerProps> = ({
   isDesktop,
   toggleNotificationDrawer,
-  toggleNotificationsRead,
   isDrawerExpanded,
   onDrawerChange,
-  notificationsRead,
   alerts,
   children,
 }) => {
+  const { t } = useTranslation();
   React.useEffect(() => {
     const poll: NotificationPoll = (url, key: 'notificationAlerts' | 'silences', dataHandler) => {
       store.dispatch(UIActions.monitoringLoading(key));
@@ -163,17 +238,20 @@ export const ConnectedNotificationDrawer_: React.FC<ConnectedNotificationDrawerP
     const { alertManagerBaseURL, prometheusBaseURL } = window.SERVER_FLAGS;
 
     if (prometheusBaseURL) {
-      poll(`${prometheusBaseURL}/api/v1/rules`, 'notificationAlerts', getAlerts);
+      poll(`${prometheusBaseURL}/${PrometheusEndpoint.RULES}`, 'notificationAlerts', getAlerts);
     } else {
       store.dispatch(
-        UIActions.monitoringErrored('notificationAlerts', new Error('prometheusBaseURL not set')),
+        UIActions.monitoringErrored(
+          'notificationAlerts',
+          new Error(t('notification-drawer~prometheusBaseURL not set')),
+        ),
       );
     }
 
     if (alertManagerBaseURL) {
-      poll(`${alertManagerBaseURL}/api/v1/silences`, 'silences', ({ data }) => {
+      poll(`${alertManagerBaseURL}/api/v2/silences`, 'silences', (silences) => {
         // Set a name field on the Silence to make things easier
-        _.each(data, (s) => {
+        _.each(silences, (s) => {
           s.name = _.get(_.find(s.matchers, { name: 'alertname' }), 'value');
           if (!s.name) {
             // No alertname, so fall back to displaying the other matchers
@@ -182,20 +260,22 @@ export const ConnectedNotificationDrawer_: React.FC<ConnectedNotificationDrawerP
               .join(', ');
           }
         });
-        return data;
+        return silences;
       });
     } else {
       store.dispatch(
-        UIActions.monitoringErrored('silences', new Error('alertManagerBaseURL not set')),
+        UIActions.monitoringErrored(
+          'silences',
+          new Error(t('notification-drawer~alertManagerBaseURL not set')),
+        ),
       );
     }
 
     return () => _.each(pollerTimeouts, clearTimeout);
-  }, []);
-  const [clusterVersionData, clusterVersionLoaded] = useK8sWatchResource<ClusterVersionKind>(
-    cvResource,
-  );
-  const updateData: ClusterUpdate[] = getSortedUpdates(clusterVersionData);
+  }, [t]);
+  const [clusterVersionData] = useK8sWatchResource<ClusterVersionKind>(cvResource);
+  const alertActionExtensions = useExtensions<AlertAction>(isAlertAction);
+
   const { data, loaded, loadError } = alerts || {};
 
   const clusterVersionIsEditable =
@@ -207,8 +287,7 @@ export const ConnectedNotificationDrawer_: React.FC<ConnectedNotificationDrawerP
     }) && window.SERVER_FLAGS.branding !== 'dedicated';
 
   const updateList: React.ReactNode[] = getUpdateNotificationEntries(
-    clusterVersionLoaded,
-    updateData,
+    clusterVersionData,
     clusterVersionIsEditable,
     toggleNotificationDrawer,
   );
@@ -216,12 +295,14 @@ export const ConnectedNotificationDrawer_: React.FC<ConnectedNotificationDrawerP
     true,
     data,
     toggleNotificationDrawer,
+    alertActionExtensions,
     true,
   );
   const otherAlertList: React.ReactNode[] = getAlertNotificationEntries(
     loaded,
     data,
     toggleNotificationDrawer,
+    alertActionExtensions,
     false,
   );
   const [isAlertExpanded, toggleAlertExpanded] = React.useState<boolean>(
@@ -264,7 +345,7 @@ export const ConnectedNotificationDrawer_: React.FC<ConnectedNotificationDrawerP
     <NotificationCategory
       key="critical-alerts"
       isExpanded={isAlertExpanded}
-      label="Critical Alerts"
+      label={t('notification-drawer~Critical Alerts')}
       count={criticalAlertList.length}
       onExpandContents={toggleAlertExpanded}
     >
@@ -275,7 +356,7 @@ export const ConnectedNotificationDrawer_: React.FC<ConnectedNotificationDrawerP
     <NotificationCategory
       key="other-alerts"
       isExpanded={isNonCriticalAlertExpanded}
-      label="Other Alerts"
+      label={t('notification-drawer~Other Alerts')}
       count={otherAlertList.length}
       onExpandContents={toggleNonCriticalAlertExpanded}
     >
@@ -283,11 +364,11 @@ export const ConnectedNotificationDrawer_: React.FC<ConnectedNotificationDrawerP
     </NotificationCategory>
   ) : null;
 
-  const messageCategory: React.ReactElement = !_.isEmpty(updateList) ? (
+  const recommendationsCategory: React.ReactElement = !_.isEmpty(updateList) ? (
     <NotificationCategory
-      key="messages"
+      key="recommendations"
       isExpanded={isClusterUpdateExpanded}
-      label="Messages"
+      label={t('notification-drawer~Recommendations')}
       count={updateList.length}
       onExpandContents={toggleClusterUpdateExpanded}
     >
@@ -295,18 +376,17 @@ export const ConnectedNotificationDrawer_: React.FC<ConnectedNotificationDrawerP
     </NotificationCategory>
   ) : null;
 
-  if (_.isEmpty(data) && _.isEmpty(updateList) && !notificationsRead) {
-    toggleNotificationsRead();
-  } else if ((!_.isEmpty(data) || !_.isEmpty(updateList)) && notificationsRead) {
-    toggleNotificationsRead();
-  }
-
   return (
     <NotificationDrawer
       className="co-notification-drawer"
       isInline={isDesktop}
       isExpanded={isDrawerExpanded}
-      notificationEntries={[criticalAlertCategory, nonCriticalAlertCategory, messageCategory]}
+      notificationEntries={[
+        criticalAlertCategory,
+        nonCriticalAlertCategory,
+        recommendationsCategory,
+      ]}
+      onClose={toggleNotificationDrawer}
     >
       {children}
     </NotificationDrawer>
@@ -321,7 +401,6 @@ type NotificationPoll = (
 
 export type WithNotificationsProps = {
   isDrawerExpanded: boolean;
-  notificationsRead: boolean;
   alerts?: {
     data: Alert[];
     loaded: boolean;
@@ -334,17 +413,14 @@ export type WithNotificationsProps = {
 
 export type ConnectedNotificationDrawerProps = {
   isDesktop: boolean;
-  toggleNotificationsRead: () => any;
   toggleNotificationDrawer: () => any;
   isDrawerExpanded: boolean;
-  notificationsRead: boolean;
   onDrawerChange: () => void;
   alerts: NotificationAlerts;
 };
 
 const notificationStateToProps = ({ UI }: RootState): WithNotificationsProps => ({
   isDrawerExpanded: !!UI.getIn(['notifications', 'isExpanded']),
-  notificationsRead: !!UI.getIn(['notifications', 'isRead']),
   alerts: UI.getIn(['monitoring', 'notificationAlerts']),
   silences: UI.getIn(['monitoring', 'silences']),
 });
@@ -359,6 +435,5 @@ type AlertEmptyProps = {
 
 const connectToNotifications = connect((state: RootState) => notificationStateToProps(state), {
   toggleNotificationDrawer: UIActions.notificationDrawerToggleExpanded,
-  toggleNotificationsRead: UIActions.notificationDrawerToggleRead,
 });
 export const ConnectedNotificationDrawer = connectToNotifications(ConnectedNotificationDrawer_);
